==> cards-0.1.1.tgz: package/src/components/grid.jsx <==
import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '@foundation/core'

/**
 * Display a scrollable grid layout.
 * 
 * @param  {number} props.verticalPadding - Top and bottom padding for the grid
 * @param  {number} props.columns         - Number of columns to display
 * @param  {string} props.justify         - Determines how to justify content
 * @param  {object} props.style           - Override or add any additional styles
 * @param  {object} props.children        - Typically a set of `<Card />`s
 * @return {object}                       - React markup
 */
const Grid = React.forwardRef(({
    verticalPadding = 24,
    columns = 4,
    justify = 'center',
    style = {},
    children
}, ref) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <div
            ref={ref}
            style={{
                position: 'relative',
                flex: '1 1 auto',
                overflow: 'auto',
                paddingBottom: verticalPadding,
                ...style
            }}
        >
            <figure style={{
                position: 'sticky',
                top: 0,
                width: '100%',
                height: verticalPadding,
                zIndex: 5,
                background: `linear-gradient(
                    to bottom,
                    ${neutral[1]} 20%,
                    transparent 80%
                )`
            }} />
            <div style={{
                display: 'grid',
                gridTemplateAreas: `'${new Array(columns).fill('a').join(' ')}'`,
                gridAutoColumns: 'max-content',
                gridAutoRows: 'max-content',
                gridGap: 16,
                justifyContent: justify
            }}>
                { children }
            </div>
        </div>
    )
})

Grid.propTypes = {
    columns: PropTypes.number,
    children: PropTypes.node
}

export default Grid

==> cards-0.2.0.tgz: package/src/components/grid.jsx <==
import React, { useContext } from 'react'
import PropTypes from 'prop-types'
import { ThemeContext } from '@foundation/core'

/**
 * Display a scrollable grid layout.
 * 
 * @param  {number} props.verticalPadding - Top and bottom padding for the grid
 * @param  {number} props.columns         - Number of columns to display
 * @param  {string} props.justify         - Determines how to justify content
 * @param  {object} props.style           - Override or add any additional styles
 * @param  {object} props.children        - Typically a set of `<Card />`s
 * @return {object}                       - React markup
 */
const Grid = React.forwardRef(({
    verticalPadding = 24,
    columns = 4,
    gap = 16,
    justify = 'center',
    style = {},
    children
}, ref) => {
    const { neutral } = useContext(ThemeContext)

    return (
        <div
            ref={ref}
            style={{
                position: 'relative',
                flex: '1 1 auto',
                overflow: 'auto',
                paddingBottom: verticalPadding,
                ...style
            }}
        >
            <figure style={{
                position: 'sticky',
                top: 0,
                width: '100%',
                height: verticalPadding,
                zIndex: 5,
                // background: `linear-gradient(
                //     to bottom,
                //     ${neutral[1]} 20%,
                //     transparent 80%
                // )`
            }} />
            <div style={{
                display: 'grid',
                gridTemplateAreas: `'${new Array(columns).fill('a').join(' ')}'`,
                gridAutoColumns: 'max-content',
                gridAutoRows: 'max-content',
                gridGap: gap,
                justifyContent: justify
            }}>
                { children }
            </div>
        </div>
    )
})

Grid.propTypes = {
    columns: PropTypes.number,
    children: PropTypes.node
}

export default Grid
